// AlphaInterfaces.h
// (c) 2003-2004 exeal

#ifndef _ALPHA_INTERFACES_H_
#define _ALPHA_INTERFACES_H_


namespace Alpha {
	///	ۑ\ȃIuWFNg
	///	@see	CKeyboardMap
	interface ISerializable {
		///	fXgN^
		virtual ~ISerializable() {}
		///	ύXĂۑĂȂ true Ԃ
		virtual bool	IsDirty() const = 0;
		/**
		 *	t@Cǂݍ
		 *	@param pwszPathName	t@CpX
		 *	@return				
		 */
		virtual bool	Load(const wchar_t* pwszPathName) = 0;
		/**
		 *	t@Cɕۑ
		 *	@param pwszPathName	t@CpX
		 *	@return				
		 */
		virtual bool	Save(const wchar_t* pwszPathName) = 0;
	};
}

#endif /* _ALPHA_INTERFACES_H_ */

/* [EOF] */